@@ -1,6 +1,4 @@
-BEGIN {
-    $Physics::Unit::Vector::debug = 1;
-}
+BEGIN { $Physics::Unit::Vector::debug = 1; }
 
 use Physics::Unit::Vector;
 
