@@ -1,5 +1,7 @@
 package Physics::Unit;
 
+print "howdy!\n";
+
 use strict;
 use Carp;
 use base qw(Exporter);
@@ -11,10 +13,7 @@ use vars qw(
     $number_re
 );
 
-$VERSION = '0.04_02';
-$VERSION = eval $VERSION;
-
-@EXPORT_OK = qw(
+my @export_ok_list = qw(
     $number_re
     GetTypeUnit
     GetUnit
@@ -27,7 +26,9 @@ $VERSION = eval $VERSION;
     NumBases
 );
 
-%EXPORT_TAGS = ('ALL' => \@EXPORT_OK);
+%EXPORT_TAGS = ('ALL' => \@export_ok_list);
+@EXPORT_OK   = @export_ok_list;
+$VERSION = '0.02';
 
 # This is the regular expression used to parse out a number.  It
 # is here so that other modules can use it for convenience.
@@ -63,7 +64,7 @@ my $NumBases = 0;
 my @BaseName;
 
 InitBaseUnit (
-    'Distance'    => ['meter', 'm', 'meters', 'metre', 'metres'],
+    'Distance'    => ['meter', 'm', 'meters'],
     'Mass'        => ['gram', 'gm', 'grams'],
     'Time'        => ['second', 's', 'sec', 'secs', 'seconds'],
     'Temperature' => ['kelvin', 'k', 'kelvins',
@@ -231,7 +232,6 @@ InitUnit (
     ['ug',],                                    'microgram',        # exact
 
     ['dram', 'drams'],                          'ounce / 16',       # exact
-
     ['troy-pound', 'troy-pounds'],              '0.373 kg',
     ['troy-ounce', 'troy-ounces',
      'ounce-troy', 'ounces-troy'],              '31.103 gm',
@@ -1495,7 +1495,7 @@ Or, you can just get specific ones. For example:
 
   use Physics::Unit qw( GetUnit ListUnits );
 
-=head1 PACKAGE VARIABLES
+=head1 Class Data
 
 =head2 $debug
 
@@ -1515,7 +1515,40 @@ here so that other modules can use it for convenience.
 A (correct) regular expression for a floating point number,
 optionally in exponent form. This is hard to come by.
 
-This variable may also be imported for ease of use.
+=head2 %reserved_word
+
+A list of reserved words in Unit expressions.
+
+=head2 %unit_by_name
+
+A list of all known unit names. The value of the hash is a reference
+to the named unit object.
+
+=head2 %prefix
+
+A list of all the valid prefixes. The value of the hash is a
+reference to the unit object. Note that the names here are also in
+%unit_by_name.
+
+These are special case unit names that can be attached to other units
+with no intervening spaces.
+
+=head2 %prototype
+
+A list of all the known types. The values of this hash are references
+to unit objects that exemplify these types. I.e., any other units
+that have the same type will have the same dimensionality as the
+example unit.
+
+=head2 $NumBases
+
+The number of base units.
+
+=head2 @BaseName
+
+The name of each of the base units. These names also appear in
+%unit_by_name.
+
 
 
 =head1 PUBLIC UTILITY FUNCTIONS
